@@ -861,27 +861,8 @@ class LessonFileManager:
                 if filename in ('.arch-ids', 'Makefile', 'Makefile.in') \
                   or not os.path.isfile(self.get_complete_filename(collection, filename)):
                     continue
-                # We save the returned lesson_id because we need it below
-                lesson_id = self.parse_into_uiddb(collection, filename)
-                # We have to check if the lesson file has changed,
-                # and if it has, then the results has to be deleted.
-                # This because Solfege has no way of knowing what kind
-                # of changes has been done to the lesson file.
-                fn = self.get_complete_filename(collection, filename)
-                h = hash(open(fn, 'r').read())
-                hash_filename = os.path.join(os.path.expanduser("~/.solfege"),
-                           "testresults", "%s_hash" % lesson_id)
-                if os.path.exists(hash_filename):
-                    h2 = int(open(hash_filename, 'r').read())
-                    if h != h2:
-                        dirname = os.path.join(gethomedir.get_home_dir(),
-                                ".solfege", "testresults", lesson_id)
-                        for f in os.listdir(dirname):
-                            os.remove(os.path.join(dirname, f))
+                self.parse_into_uiddb(collection, filename)
     def parse_into_uiddb(self, collection, filename):
-                """
-                Returns the lesson_id of the parsed file.
-                """
                 fn = self.get_complete_filename(collection, filename)
                 try:
                     f = LessonIdParser(fn)
@@ -913,7 +894,6 @@ class LessonFileManager:
                         self.m_uiddb[p.header['lesson_id']] = \
                             [self.m_uiddb[p.header['lesson_id']]]
                     self.m_uiddb[p.header['lesson_id']].append(n)
-                return p.header['lesson_id']
     def create_lessonfile_index(self):
         self.m_htmldoc = """<html></head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8"></head><body><p>%s</p>""" % _("This page lists all the lesson files that Solfege can find. You can click on the links to start practising.")
         d = {}
